@@ -51,8 +51,7 @@ def generate_example_rst(app):
             relpath = os.path.split(root)[-1]
             datad.setdefault(relpath, []).append((fullpath, fname, contents))
 
-    subdirs = list(datad.keys())
-    subdirs.sort()
+    subdirs = sorted(datad)
 
     fhindex = open(os.path.join(exampledir, 'index.rst'), 'w')
     fhindex.write("""\
@@ -169,3 +168,6 @@ def setup(app):
         app.add_config_value('mpl_example_sections', [], True)
     except sphinx.errors.ExtensionError:
         pass # mpl_example_sections already defined
+
+    metadata = {'parallel_read_safe': True, 'parallel_write_safe': True}
+    return metadata
