@@ -1,25 +1,42 @@
+"""
+=====
+Decay
+=====
+
+A sinusoidal decay animation.
+"""
+
+
 import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 
-def data_gen():
-    t = data_gen.t
+
+def data_gen(t=0):
     cnt = 0
     while cnt < 1000:
-        cnt+=1
-        t += 0.05
+        cnt += 1
+        t += 0.1
         yield t, np.sin(2*np.pi*t) * np.exp(-t/10.)
-data_gen.t = 0
+
+
+def init():
+    ax.set_ylim(-1.1, 1.1)
+    ax.set_xlim(0, 10)
+    del xdata[:]
+    del ydata[:]
+    line.set_data(xdata, ydata)
+    return line,
 
 fig, ax = plt.subplots()
 line, = ax.plot([], [], lw=2)
-ax.set_ylim(-1.1, 1.1)
-ax.set_xlim(0, 5)
 ax.grid()
 xdata, ydata = [], []
+
+
 def run(data):
     # update the data
-    t,y = data
+    t, y = data
     xdata.append(t)
     ydata.append(y)
     xmin, xmax = ax.get_xlim()
@@ -31,6 +48,6 @@ def run(data):
 
     return line,
 
-ani = animation.FuncAnimation(fig, run, data_gen, blit=True, interval=10,
-    repeat=False)
+ani = animation.FuncAnimation(fig, run, data_gen, blit=False, interval=10,
+                              repeat=False, init_func=init)
 plt.show()
