@@ -3,8 +3,8 @@
 Simple animation examples
 =========================
 
-This example contains two animations. The first is a random walk plot. The
-second is an image animation.
+Two animations where the first is a random walk plot and
+the second is an image animation.
 """
 
 import numpy as np
@@ -16,8 +16,13 @@ def update_line(num, data, line):
     line.set_data(data[..., :num])
     return line,
 
+###############################################################################
+
 fig1 = plt.figure()
 
+# Fixing random state for reproducibility
+np.random.seed(19680801)
+
 data = np.random.rand(2, 25)
 l, = plt.plot([], [], 'r-')
 plt.xlim(0, 1)
@@ -29,6 +34,8 @@ line_ani = animation.FuncAnimation(fig1, update_line, 25, fargs=(data, l),
 
 # To save the animation, use the command: line_ani.save('lines.mp4')
 
+###############################################################################
+
 fig2 = plt.figure()
 
 x = np.arange(-9, 10)
